==> jc-1.4.0.tar.gz: javax/swing/plaf/MenuItemUI.h <==
// public abstract class javax.swing.plaf.MenuItemUI

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5216db2ca259b37f javax_swing_plaf_ButtonUI
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class 1c57b3e4816d873f javax_swing_plaf_MenuItemUI

// header file dependencies
// @dep_header javax_swing_plaf_ButtonUI

#include "javax/swing/plaf/ButtonUI.h"

#ifndef _JC_javax_swing_plaf_MenuItemUI_H_
#define _JC_javax_swing_plaf_MenuItemUI_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_MenuItemUI$sub_refs	_jc_javax_swing_plaf_MenuItemUI$sub_refs;
typedef struct _jc_javax_swing_plaf_MenuItemUI$sub_nonrefs	_jc_javax_swing_plaf_MenuItemUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_MenuItemUI$refs	_jc_javax_swing_plaf_MenuItemUI$refs;
typedef struct _jc_javax_swing_plaf_MenuItemUI$nonrefs	_jc_javax_swing_plaf_MenuItemUI$nonrefs;
typedef struct _jc_javax_swing_plaf_MenuItemUI$object	_jc_javax_swing_plaf_MenuItemUI$object;

typedef const struct _jc_javax_swing_plaf_MenuItemUI$vmethods	_jc_javax_swing_plaf_MenuItemUI$vmethods;
typedef const struct _jc_javax_swing_plaf_MenuItemUI$vtable	_jc_javax_swing_plaf_MenuItemUI$vtable;
typedef const struct _jc_javax_swing_plaf_MenuItemUI$vtype	_jc_javax_swing_plaf_MenuItemUI$vtype;

// Constructors
extern void _jc_javax_swing_plaf_MenuItemUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_MenuItemUI$object *);

// Virtual methods structure
struct _jc_javax_swing_plaf_MenuItemUI$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_MenuItemUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_ButtonUI$vmethods	javax_swing_plaf_ButtonUI;
	_jc_javax_swing_plaf_MenuItemUI$vmethods	javax_swing_plaf_MenuItemUI;
};

// Vtype
struct _jc_javax_swing_plaf_MenuItemUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_MenuItemUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_MenuItemUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_MenuItemUI$refs {
    _jc_javax_swing_plaf_MenuItemUI$sub_refs	javax_swing_plaf_MenuItemUI;
    _jc_javax_swing_plaf_ButtonUI$sub_refs	javax_swing_plaf_ButtonUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_MenuItemUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_MenuItemUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_ButtonUI$sub_nonrefs	javax_swing_plaf_ButtonUI;
    _jc_javax_swing_plaf_MenuItemUI$sub_nonrefs	javax_swing_plaf_MenuItemUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_MenuItemUI$object {
	_jc_javax_swing_plaf_MenuItemUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_MenuItemUI$vtype	*vtype;
	_jc_javax_swing_plaf_MenuItemUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_MenuItemUI$vtype _jc_javax_swing_plaf_MenuItemUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_MenuItemUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_MenuItemUI$class_object;

#endif	/* _JC_javax_swing_plaf_MenuItemUI_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/MenuItemUI.h <==
// public abstract class javax.swing.plaf.MenuItemUI

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5216db2ca259b37f javax_swing_plaf_ButtonUI
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class 1c57b3e4816d873f javax_swing_plaf_MenuItemUI

// header file dependencies
// @dep_header javax_swing_plaf_ButtonUI

#include "javax/swing/plaf/ButtonUI.h"

#ifndef _JC_javax_swing_plaf_MenuItemUI_H_
#define _JC_javax_swing_plaf_MenuItemUI_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_MenuItemUI$sub_refs	_jc_javax_swing_plaf_MenuItemUI$sub_refs;
typedef struct _jc_javax_swing_plaf_MenuItemUI$sub_nonrefs	_jc_javax_swing_plaf_MenuItemUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_MenuItemUI$refs	_jc_javax_swing_plaf_MenuItemUI$refs;
typedef struct _jc_javax_swing_plaf_MenuItemUI$nonrefs	_jc_javax_swing_plaf_MenuItemUI$nonrefs;
typedef struct _jc_javax_swing_plaf_MenuItemUI$object	_jc_javax_swing_plaf_MenuItemUI$object;

typedef const struct _jc_javax_swing_plaf_MenuItemUI$vmethods	_jc_javax_swing_plaf_MenuItemUI$vmethods;
typedef const struct _jc_javax_swing_plaf_MenuItemUI$vtable	_jc_javax_swing_plaf_MenuItemUI$vtable;
typedef const struct _jc_javax_swing_plaf_MenuItemUI$vtype	_jc_javax_swing_plaf_MenuItemUI$vtype;

// Constructors
extern void _jc_javax_swing_plaf_MenuItemUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_MenuItemUI$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_plaf_MenuItemUI$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_MenuItemUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_ButtonUI$vmethods	javax_swing_plaf_ButtonUI;
	_jc_javax_swing_plaf_MenuItemUI$vmethods	javax_swing_plaf_MenuItemUI;
};

// Vtype
struct _jc_javax_swing_plaf_MenuItemUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_MenuItemUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_MenuItemUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_MenuItemUI$refs {
    _jc_javax_swing_plaf_MenuItemUI$sub_refs	javax_swing_plaf_MenuItemUI;
    _jc_javax_swing_plaf_ButtonUI$sub_refs	javax_swing_plaf_ButtonUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_MenuItemUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_MenuItemUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_ButtonUI$sub_nonrefs	javax_swing_plaf_ButtonUI;
    _jc_javax_swing_plaf_MenuItemUI$sub_nonrefs	javax_swing_plaf_MenuItemUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_MenuItemUI$object {
	_jc_javax_swing_plaf_MenuItemUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_MenuItemUI$vtype	*vtype;
	_jc_javax_swing_plaf_MenuItemUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_MenuItemUI$vtype _jc_javax_swing_plaf_MenuItemUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_MenuItemUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_MenuItemUI$class_object;

#endif	/* _JC_javax_swing_plaf_MenuItemUI_H_ */
